@@ -71,4 +71,11 @@ def preload_settings_json(request):
         }
     )
 
+    if (
+        request.user.is_authenticated
+        and request.user.is_staff
+        and request.settings.show_admin_panel_link_in_ui
+    ):
+        request.frontend_context["ADMIN_URL"] = reverse("misago:admin:index")
+
     return {}
