@@ -8,8 +8,8 @@ from snapshottest import Snapshot
 snapshots = Snapshot()
 
 snapshots[
-    "test_finalization_sets_translation_strings_in_quotes 1"
-] = '<div class="quote-heading">Quoted message:</div>'
+    "test_finalization_sets_translation_strings_in_empty_quotes_headings 1"
+] = '<div class="quote-heading" data-noquote="1">Quoted message:</div>'
 
 snapshots[
     "test_finalization_sets_translation_strings_in_spoilers_buttons 1"
