@@ -3,6 +3,7 @@ from rest_framework import serializers
 
 from . import PostingEndpoint, PostingMiddleware
 from ....markup import common_flavour
+from ....readtracker.poststracker import save_read
 from ....users.audittrail import create_audit_trail
 from ...checksums import update_post_checksum
 from ...validators import validate_post, validate_post_length, validate_thread_title
@@ -45,6 +46,9 @@ class ReplyMiddleware(PostingMiddleware):
             self.thread.set_first_post(self.post)
             self.thread.set_last_post(self.post)
 
+        if self.mode in (PostingEndpoint.START, PostingEndpoint.REPLY):
+            save_read(self.user, self.post)
+
         self.thread.save()
 
         create_audit_trail(self.request, self.post)
